==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_whats_new_13_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_13.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_13.xml#Introduction',
'whats_new_13.xml#12-29',
'whats_new_13.xml#12-27',
'whats_new_13.xml#12-26',
'whats_new_13.xml#12-24',
'whats_new_13.xml#11-27',
'whats_new_13.xml#11-13',
'whats_new_13.xml#11-12',
'whats_new_13.xml#10-29',
'whats_new_13.xml#10-23',
'whats_new_13.xml#10-22',
'whats_new_13.xml#10-16',
'whats_new_13.xml#10-15',
'whats_new_13.xml#10-14',
'whats_new_13.xml#10-13',
'whats_new_13.xml#10-12',
'whats_new_13.xml#09-20',
'whats_new_13.xml#09-19',
'whats_new_13.xml#09-18',
'whats_new_13.xml#09-07',
'whats_new_13.xml#08-12',
'whats_new_13.xml#08-11',
'whats_new_13.xml#08-06',
'whats_new_13.xml#07-26',
'whats_new_13.xml#05-28',
'whats_new_13.xml#05-21',
'whats_new_13.xml#05-17',
'whats_new_13.xml#05-15',
'whats_new_13.xml#05-14',
'whats_new_13.xml#05-12',
'whats_new_13.xml#05-11',
'whats_new_13.xml#05-04',
'whats_new_13.xml#04-28',
'whats_new_13.xml#04-27',
'whats_new_13.xml#04-26'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_whats_new_13_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_13.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'whats_new_15.xml',
'whats_new_14.xml',
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_13.xml#Introduction',
'whats_new_13.xml#12-29',
'whats_new_13.xml#12-27',
'whats_new_13.xml#12-26',
'whats_new_13.xml#12-24',
'whats_new_13.xml#11-27',
'whats_new_13.xml#11-13',
'whats_new_13.xml#11-12',
'whats_new_13.xml#10-29',
'whats_new_13.xml#10-23',
'whats_new_13.xml#10-22',
'whats_new_13.xml#10-16',
'whats_new_13.xml#10-15',
'whats_new_13.xml#10-14',
'whats_new_13.xml#10-13',
'whats_new_13.xml#10-12',
'whats_new_13.xml#09-20',
'whats_new_13.xml#09-19',
'whats_new_13.xml#09-18',
'whats_new_13.xml#09-07',
'whats_new_13.xml#08-12',
'whats_new_13.xml#08-11',
'whats_new_13.xml#08-06',
'whats_new_13.xml#07-26',
'whats_new_13.xml#05-28',
'whats_new_13.xml#05-21',
'whats_new_13.xml#05-17',
'whats_new_13.xml#05-15',
'whats_new_13.xml#05-14',
'whats_new_13.xml#05-12',
'whats_new_13.xml#05-11',
'whats_new_13.xml#05-04',
'whats_new_13.xml#04-28',
'whats_new_13.xml#04-27',
'whats_new_13.xml#04-26'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
